@@ -56,7 +56,10 @@ class RawMetadata(object):
         return self._metadata_parsed
 
     def _set_default_if_not_empty(self, entry):
-        if len(self._metadata_parsed[entry]) == 0 and self._metadata_parsed['total_images_per_channel'] > 0:
+        total_images = self._metadata_parsed['total_images_per_channel'] \
+            if self._metadata_parsed['total_images_per_channel'] is not None else 0
+
+        if len(self._metadata_parsed[entry]) == 0 and total_images > 0:
             # if the file is not empty, we always have one of this entry
             self._metadata_parsed[entry] = [0]
 
@@ -67,7 +70,12 @@ class RawMetadata(object):
         return None
 
     def _parse_width_or_height(self, key):
-        return self.image_attributes[six.b('SLxImageAttributes')][six.b(key)]
+        try:
+            length = self.image_attributes[six.b('SLxImageAttributes')][six.b(key)]
+        except KeyError:
+            length = None
+
+        return length
 
     def _parse_height(self):
         return self._parse_width_or_height('uiHeight')
@@ -76,10 +84,16 @@ class RawMetadata(object):
         return self._parse_width_or_height('uiWidth')
 
     def _parse_date(self):
-        return parse_date(self.image_text_info[six.b('SLxImageTextInfo')])
+        try:
+            return parse_date(self.image_text_info[six.b('SLxImageTextInfo')])
+        except KeyError:
+            return None
 
     def _parse_calibration(self):
-        return self.image_calibration.get(six.b('SLxCalibration'), {}).get(six.b('dCalibration'))
+        try:
+            return self.image_calibration.get(six.b('SLxCalibration'), {}).get(six.b('dCalibration'))
+        except KeyError:
+            return None
 
     def _parse_frames(self):
         """The number of cycles.
@@ -99,27 +113,39 @@ class RawMetadata(object):
         if self.image_metadata_sequence is None:
             return []
 
-        metadata = self.image_metadata_sequence[six.b('SLxPictureMetadata')][six.b('sPicturePlanes')]
+        try:
+            metadata = self.image_metadata_sequence[six.b('SLxPictureMetadata')][six.b('sPicturePlanes')]
+        except KeyError:
+            return []
+
         channels = self._process_channels_metadata(metadata)
 
         return channels
 
     def _process_channels_metadata(self, metadata):
+        validity = self._get_channel_validity_list(metadata)
+
+        # Channel information is contained in dictionaries with the keys a0, a1...an where the number
+        # indicates the order in which the channel is stored. So by sorting the dicts alphabetically
+        # we get the correct order.
+        channels = []
+        for valid, (label, chan) in zip(validity, sorted(metadata[six.b('sPlaneNew')].items())):
+            if not valid:
+                continue
+            if chan[six.b('sDescription')] is not None:
+                channels.append(chan[six.b('sDescription')].decode("utf8"))
+            else:
+                channels.append('Unknown')
+        return channels
+
+    def _get_channel_validity_list(self, metadata):
         try:
             validity = self.image_metadata[six.b('SLxExperiment')][six.b('ppNextLevelEx')][six.b('')][0][
                 six.b('ppNextLevelEx')][six.b('')][0][six.b('pItemValid')]
         except (KeyError, TypeError):
             # If none of the channels have been deleted, there is no validity list, so we just make one
             validity = [True for _ in metadata]
-        # Channel information is contained in dictionaries with the keys a0, a1...an where the number
-        # indicates the order in which the channel is stored. So by sorting the dicts alphabetically
-        # we get the correct order.
-        channels = []
-        for (label, chan), valid in zip(sorted(metadata[six.b('sPlaneNew')].items()), validity):
-            if not valid:
-                continue
-            channels.append(chan[six.b('sDescription')].decode("utf8"))
-        return channels
+        return validity
 
     def _parse_fields_of_view(self):
         """The metadata contains information about fields of view, but it contains it even if some fields
@@ -148,7 +174,10 @@ class RawMetadata(object):
         if self.image_text_info is None:
             return dimension_text
 
-        textinfo = self.image_text_info[six.b('SLxImageTextInfo')].values()
+        try:
+            textinfo = self.image_text_info[six.b('SLxImageTextInfo')].values()
+        except KeyError:
+            return dimension_text
 
         for line in textinfo:
             entry = self._parse_dimension_text_line(line)
@@ -186,7 +215,12 @@ class RawMetadata(object):
         """
         if self.image_attributes is None:
             return 0
-        return self.image_attributes[six.b('SLxImageAttributes')][six.b('uiSequenceCount')]
+        try:
+            total_images = self.image_attributes[six.b('SLxImageAttributes')][six.b('uiSequenceCount')]
+        except KeyError:
+            total_images = None
+
+        return total_images
 
     def _parse_roi_metadata(self):
         """Parse the raw ROI metadata.
@@ -295,23 +329,21 @@ class RawMetadata(object):
         """Parse the metadata of the ND experiment
 
         """
+        self._metadata_parsed['experiment'] = {
+            'description': 'unknown',
+            'loops': []
+        }
+
         if self.image_metadata is None or six.b('SLxExperiment') not in self.image_metadata:
             return
 
         raw_data = self.image_metadata[six.b('SLxExperiment')]
 
-        experimental_data = {
-            'description': 'unknown',
-            'loops': []
-        }
-
         if six.b('wsApplicationDesc') in raw_data:
-            experimental_data['description'] = raw_data[six.b('wsApplicationDesc')].decode('utf8')
+            self._metadata_parsed['experiment']['description'] = raw_data[six.b('wsApplicationDesc')].decode('utf8')
 
         if six.b('uLoopPars') in raw_data:
-            experimental_data['loops'] = self._parse_loop_data(raw_data[six.b('uLoopPars')])
-
-        self._metadata_parsed['experiment'] = experimental_data
+            self._metadata_parsed['experiment']['loops'] = self._parse_loop_data(raw_data[six.b('uLoopPars')])
 
     @staticmethod
     def _get_loops_from_data(loop_data):
@@ -383,9 +415,24 @@ class RawMetadata(object):
             interval = get_from_dict_if_exists('dAvgPeriodDiff', loop)
         if interval is None or interval <= 0:
             # In some cases, both keys are not saved. Then try to calculate it.
-            number_of_loops = get_from_dict_if_exists('uiCount', loop)
-            number_of_loops = number_of_loops if number_of_loops is not None and number_of_loops > 0 else 1
-            interval = duration / number_of_loops
+            interval = RawMetadata._guess_sampling_from_loops(duration, loop)
+        return interval
+
+    @staticmethod
+    def _guess_sampling_from_loops(duration, loop):
+        """ In some cases, both keys are not saved. Then try to calculate it.
+        
+        Args:
+            duration: the total duration of the loop
+            loop: the raw loop data
+
+        Returns:
+            float: the guessed sampling interval in milliseconds
+
+        """
+        number_of_loops = get_from_dict_if_exists('uiCount', loop)
+        number_of_loops = number_of_loops if number_of_loops is not None and number_of_loops > 0 else 1
+        interval = duration / number_of_loops
         return interval
 
     @property
